package com.zanxiang.sdk.controller;

import com.zanxiang.common.domain.ResultMap;
import com.zanxiang.common.utils.StringUtils;
import com.zanxiang.common.utils.bean.BeanUtils;
import com.zanxiang.sdk.common.annotation.ValidLogin;
import com.zanxiang.sdk.domain.bo.PlatformOrderBO;
import com.zanxiang.sdk.domain.params.PreOrderParam;
import com.zanxiang.sdk.domain.params.UserData;
import com.zanxiang.sdk.domain.vo.PreOrderVO;
import com.zanxiang.sdk.service.GameStrategyService;
import com.zanxiang.sdk.service.PlatformOrderService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * @author xufeng
 * @date 2022/6/17 17:07
 */
@Api(tags = "支付公共入口")
@RestController
@RequestMapping(value = "/order")
public class OrderController {
    @Autowired
    private PlatformOrderService orderService;

    @Autowired
    private GameStrategyService gameStrategyService;

    @ApiOperation(value = "订单生成")
    @PostMapping(value = "/preOrder")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = PreOrderVO.class)})
    public ResultMap preOrder(@ValidLogin UserData user, @RequestBody PreOrderParam order) {
        PlatformOrderBO orderBo = BeanUtils.copy(order, PlatformOrderBO.class);
        Boolean paySwitch = gameStrategyService.paySwitch(user, orderBo);
        orderBo.setIsSwitch(paySwitch);
        String orderId = orderService.create(orderBo);
        if (StringUtils.isEmpty(orderId)) {
            return ResultMap.error("生成订单失败");
        }
        PreOrderVO data = new PreOrderVO();
        data.setOrderId(orderId);
        data.setPaySwitch(paySwitch);
        return ResultMap.ok(data);
    }
}
